==> larus_board-1.1.2.zip: larus_board-1.1.2/lb_private/lang/en/acp.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009,2010 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'access_control'=>'Access Control',
'account_successfully_deleted'=>'This user has been deleted.',
'ace_to_group'=>'To Group',
'ace_to_user'=>'To User',
'acp_overview'=>'Executive Overview',
'add_a_new_group'=>'Add a new user group',
'add_a_new_prefix'=>'Add a new post prefix',
'check_for_update'=>'Check for Software Update',
'choose_data'=>'Choose data',
'choose_ip'=>'Limit to IP-Address',
'choose_level'=>'Choose Level',
'choose_time'=>'Choose Time',
'choose_zoom'=>'Time Series',
'color'=>'Color',
'configuration'=>'Configuration',
'currently_no_log_entries'=>'No log entries match your criteria!',
'database_version'=>'Database Version',
'database_version_is_too_old_please_upgrade'=>'The current version of this software requires a more recent database structure than you have. Please rerun setup and update your database.',
'delete_ace_successful'=>'This access control entry has been removed.',
'delete_group_successful'=>'This user group has been deleted.',
'delete_prefix_successful'=>'This post prefix has been deleted.',
'edit_acl'=>'Set Permissions',
'edit_acl_successful'=>'This access control list has been edited.',
'edit_cfg'=>'Set Options',
'edit_cfg_successful'=>'Your configuration has been edited.',
'edit_group'=>'Edit User Group',
'edit_group_acl'=>'Edit Group-Access',
'edit_group_normal'=>'Edit common group data',
'edit_group_successful'=>'This user group has been edited.',
'edit_prefix'=>'Edit Prefix',
'edit_prefix_successful'=>'This post prefix has been edited.',
'edit_task'=>'Edit Task',
'edit_task_successful'=>'This task has been edited.',
'explain_choose_ip'=>'Limit results to an IP-Address?',
'explain_choose_level'=>'Limit results to a level?',
'explain_choose_time'=>'Choose a time.',
'explain_group_color'=>'This color is used to represent the group.',
'explain_group_name'=>'Set the name of this group.',
'explain_group_permission_copy'=>'Select a group you want to copy the permissions from to the new one.',
'explain_group_permission_ex'=>'Does this group have executive permissions?',
'explain_group_permission_pa'=>'Should new postings be approved immediately?',
'explain_group_permission_pf'=>'May postings from this group be checked by the filtering system for unwanted one prior sending?',
'explain_group_permission_pr'=>'Is this group allowed to submit repeated postings?',
'explain_group_permission_ra'=>'Can this group read unapproved postings?',
'explain_group_post_weight'=>'Maximum weight for any submitted posting.',
'explain_list_as_request'=>'Do postings having this prefix be listed on moderation and executive panel as "pending request"?',
'explain_order_by'=>'Select how to order results.',
'explain_prefix_acl'=>'If this prefix is applied to a posting these permissions are inherited.',
'explain_prefix_name'=>'Set the name of this prefix.',
'explain_task_interval'=>'At what interval should this task be run? Value: <u>seconds</u>',
'explain_user'=>'Limit results to an user?',
'forum_is_not_running'=>'This forum is set to maintenance mode. Only privileged users can access it.',
'global_announcement_published'=>'The global announcement has been published.',
'group_id'=>'Group-ID',
'group_is_not_empty'=>'This user group still has assigned members.',
'group_permission_copy'=>'Copy Group Permission',
'group_permission_ex'=>'Group Permission: Executive',
'group_permission_pa'=>'Group Permission: Post Approved',
'group_permission_pf'=>'Group Permission: Posting Filter',
'group_permission_pr'=>'Group Permission: Post Repeat',
'group_permission_ra'=>'Group Permission: Read Unapproved',
'group_post_weight'=>'Highest Post Weight',
'help_and_support'=>'Help and Support',
'installed_new_task'=>'Installed the following task(s)',
'ip_address'=>'IP-Address',
'list_as_request'=>'Enlist it as Request',
'log_action'=>'Log Action',
'log_info'=>'Information',
'log_level'=>'Log Level',
'log_level_both'=>'Both',
'log_level_error'=>'Error',
'log_level_info'=>'Info',
'log_level_system'=>'Core Level',
'log_text'=>'Message',
'log_view'=>'Log View',
'monthly'=>'Monthly',
'new_ace'=>'Add a new user to list',
'new_ace_successful'=>'A new access control entry has been inserted.',
'new_forum_software_version_available'=>'The update server reports a <a href="%s" target="_blank">new version (%s)</a> is available for download.',
'new_group_successful'=>'A new user group has been added.',
'new_prefix_successful'=>'A new post prefix has been added.',
'next_task'=>'Next scheduled task',
'no_new_task_found'=>'No new tasks were found...',
'php_version'=>'PHP Version',
'please_select_action'=>'Please select an action to edit',
'please_select_class'=>'Please select configuration area to edit',
'please_select_group'=>'Please select a user group to edit',
'please_select_prefix'=>'Please select a post prefix to edit',
'please_select_task'=>'Please select a task to edit',
'post_prefix'=>'Post Prefix',
'prefix_acl'=>'Access Control Preset',
'prefix_is_not_empty'=>'This post prefix still has assigned postings.',
'publish_global_announcement'=>'Publish Global Announcement',
'purge_acl_cache'=>'Purge ACL Cache',
'purge_main_cache'=>'Purge Main Cache',
'recent_log_entries'=>'Recent log entries',
'run_soonest'=>'soonest on',
'scan_for_new_task'=>'Scan for new task files',
'scheduled_task'=>'Scheduled Task',
'security_advisory_issued_for_your_version'=>'There is a <a href="%s" target="_blank">security advisory</a> (%s) issued for your version.',
'select_time'=>'Select Time',
'statistic'=>'Statistic',
'statistic_data_account'=>'Registered Accounts',
'statistic_data_exception'=>'Software Exceptions',
'statistic_data_filter'=>'Filtered Postings',
'statistic_data_login'=>'Number of Logins',
'statistic_data_password'=>'Requested Passwords',
'statistic_data_posting'=>'Submitted Postings',
'statistic_data_search'=>'Search Queries',
'stat_post_total'=>'Currently stored postings',
'stat_user_registered_today'=>'Users have registered today',
'stat_user_request_total'=>'Number of pending user requests',
'stat_user_total'=>'Total amount of registered user accounts',
'st_account_activation'=>'Account Activated',
'st_account_register'=>'Account Registered',
'st_exception'=>'Software Exception',
'st_filter_ham'=>'Wanted Postings',
'st_filter_spam'=>'Unwanted Postings',
'st_login_attempt'=>'Login Attempt',
'st_login_success'=>'Login Success',
'st_password_activation'=>'Password Activated',
'st_password_request'=>'Password Request',
'st_search_cached'=>'Fetched from Cache',
'st_search_query'=>'Search Queries Issued',
'st_submit_posting'=>'Submitted Posting',
'task_active'=>'Run task',
'task_description'=>'Description',
'task_explain_optimize'=>'Optimizes your database',
'task_explain_post_timespan'=>'Calculates the oldest/youngest posting',
'task_explain_prune_log'=>'Purges expired log entries from database',
'task_explain_prune_request'=>'Purges expired user requests from database',
'task_explain_prune_search'=>'Purges expired search results from database',
'task_explain_prune_user'=>'Purges not activated user accounts from database',
'task_info'=>'Task Information',
'task_interval'=>'Run Interval',
'task_last_run'=>'Last run timestamp',
'task_next_run'=>'Next run (soonest)',
'task_seg_optimize'=>'Task: Optimize forum database',
'task_seg_post_timespan'=>'Task: Create main overview calendar',
'task_seg_prune_log'=>'Task: Purge Log-Records',
'task_seg_prune_request'=>'Task: Prune user requests',
'task_seg_prune_search'=>'Task: Prune search table',
'task_seg_prune_user'=>'Task: Prune user accounts',
'used_ip_addresses'=>'Used IP-Addresses',
'user_group'=>'User Group',
'using_recent_forum_software_version'=>'The update server reports that you are using the most recent version.',
'version'=>'Current version',
'yearly'=>'Yearly'
);
?>

==> larus_board-1.2.0.zip: larus_board-1.2.0/lb_private/lang/en/acp.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009,2010 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'access_control'=>'Access Control',
'account_successfully_deleted'=>'This user has been deleted.',
'ace_to_group'=>'To Group',
'ace_to_user'=>'To User',
'acp_overview'=>'Executive Overview',
'add_a_new_group'=>'Add a new user group',
'add_a_new_prefix'=>'Add a new post prefix',
'check_for_update'=>'Check for Software Update',
'choose_data'=>'Choose data',
'choose_ip'=>'Limit to IP-Address',
'choose_level'=>'Choose Level',
'choose_time'=>'Choose Time',
'choose_zoom'=>'Time Series',
'color'=>'Color',
'configuration'=>'Configuration',
'currently_no_log_entries'=>'No log entries match your criteria!',
'database_version'=>'Database Version',
'database_version_is_too_old_please_upgrade'=>'The current version of this software requires a more recent database structure than you have. Please rerun setup and update your database.',
'delete_ace_successful'=>'This access control entry has been removed.',
'delete_group_successful'=>'This user group has been deleted.',
'delete_prefix_successful'=>'This post prefix has been deleted.',
'edit_acl'=>'Set Permissions',
'edit_acl_successful'=>'This access control list has been edited.',
'edit_cfg'=>'Set Options',
'edit_cfg_successful'=>'Your configuration has been edited.',
'edit_group'=>'Edit User Group',
'edit_group_acl'=>'Edit Group-Access',
'edit_group_normal'=>'Edit common group data',
'edit_group_successful'=>'This user group has been edited.',
'edit_prefix'=>'Edit Prefix',
'edit_prefix_successful'=>'This post prefix has been edited.',
'edit_task'=>'Edit Task',
'edit_task_successful'=>'This task has been edited.',
'explain_choose_ip'=>'Limit results to an IP-Address?',
'explain_choose_level'=>'Limit results to a level?',
'explain_choose_time'=>'Choose a time.',
'explain_group_color'=>'This color is used to represent the group.',
'explain_group_name'=>'Set the name of this group.',
'explain_group_permission_copy'=>'Select a group you want to copy the permissions from to the new one.',
'explain_group_permission_ex'=>'Does this group have executive permissions? This allows them to edit foreign objects (postings, users etc.) and see all available data.',
'explain_group_permission_md'=>'Does this group have moderator permissions? This allows them to edit foreign postings only.',
'explain_group_permission_pa'=>'Should new postings be approved immediately?',
'explain_group_permission_pf'=>'May postings from this group be checked by the filtering system for unwanted one prior sending?',
'explain_group_permission_pr'=>'Is this group allowed to submit repeated postings?',
'explain_group_permission_ra'=>'Can this group read unapproved postings?',
'explain_group_post_weight'=>'Maximum weight for any submitted posting.',
'explain_list_as_request'=>'Do postings having this prefix be listed on moderation and executive panel as "pending request"?',
'explain_order_by'=>'Select how to order results.',
'explain_prefix_acl'=>'If this prefix is applied to a posting these permissions are inherited.',
'explain_prefix_name'=>'Set the name of this prefix.',
'explain_task_interval'=>'At what interval should this task be run? Value: <u>seconds</u>',
'explain_user'=>'Limit results to an user?',
'forum_is_not_running'=>'This forum is set to maintenance mode. Only privileged users can access it.',
'global_announcement_published'=>'The global announcement has been published.',
'group_id'=>'Group-ID',
'group_is_not_empty'=>'This user group still has assigned members.',
'group_permission_copy'=>'Copy Group Permission',
'group_permission_ex'=>'Group Permission: Executive',
'group_permission_md'=>'Group Permission: Moderator',
'group_permission_pa'=>'Group Permission: Post Approved',
'group_permission_pf'=>'Group Permission: Posting Filter',
'group_permission_pr'=>'Group Permission: Post Repeat',
'group_permission_ra'=>'Group Permission: Read Unapproved',
'group_post_weight'=>'Highest Post Weight',
'help_and_support'=>'Help and Support',
'installed_new_task'=>'Installed the following task(s)',
'ip_address'=>'IP-Address',
'list_as_request'=>'Enlist it as Request',
'log_action'=>'Log Action',
'log_info'=>'Information',
'log_level'=>'Log Level',
'log_level_both'=>'Both',
'log_level_error'=>'Error',
'log_level_info'=>'Info',
'log_level_system'=>'Core Level',
'log_text'=>'Message',
'log_view'=>'Log View',
'monthly'=>'Monthly',
'new_ace'=>'Add a new user to list',
'new_ace_successful'=>'A new access control entry has been inserted.',
'new_forum_software_version_available'=>'The update server reports a <a href="%s" target="_blank">new version (%s)</a> is available for download.',
'new_group_successful'=>'A new user group has been added.',
'new_prefix_successful'=>'A new post prefix has been added.',
'next_task'=>'Next scheduled task',
'no_new_task_found'=>'No new tasks were found...',
'php_version'=>'PHP Version',
'please_select_action'=>'Please select an action to edit',
'please_select_class'=>'Please select configuration area to edit',
'please_select_group'=>'Please select a user group to edit',
'please_select_prefix'=>'Please select a post prefix to edit',
'please_select_task'=>'Please select a task to edit',
'post_prefix'=>'Post Prefix',
'prefix_acl'=>'Access Control Preset',
'prefix_is_not_empty'=>'This post prefix still has assigned postings.',
'publish_global_announcement'=>'Publish Global Announcement',
'purge_acl_cache'=>'Purge ACL Cache',
'purge_main_cache'=>'Purge Main Cache',
'recent_log_entries'=>'Recent log entries',
'run_soonest'=>'soonest on',
'scan_for_new_task'=>'Scan for new task files',
'scheduled_task'=>'Scheduled Task',
'security_advisory_issued_for_your_version'=>'There is a <a href="%s" target="_blank">security advisory</a> (%s) issued for your version.',
'select_time'=>'Select Time',
'statistic'=>'Statistic',
'statistic_data_account'=>'Registered Accounts',
'statistic_data_exception'=>'Software Exceptions',
'statistic_data_filter'=>'Filtered Postings',
'statistic_data_login'=>'Number of Logins',
'statistic_data_password'=>'Requested Passwords',
'statistic_data_posting'=>'Submitted Postings',
'statistic_data_search'=>'Search Queries',
'stat_post_total'=>'Currently stored postings',
'stat_user_registered_today'=>'Users have registered today',
'stat_user_request_total'=>'Number of pending user requests',
'stat_user_total'=>'Total amount of registered user accounts',
'st_account_activation'=>'Account Activated',
'st_account_register'=>'Account Registered',
'st_exception'=>'Software Exception',
'st_filter_ham'=>'Wanted Postings',
'st_filter_spam'=>'Unwanted Postings',
'st_login_attempt'=>'Login Attempt',
'st_login_success'=>'Login Success',
'st_password_activation'=>'Password Activated',
'st_password_request'=>'Password Request',
'st_search_cached'=>'Fetched from Cache',
'st_search_query'=>'Search Queries Issued',
'st_submit_posting'=>'Submitted Posting',
'task_active'=>'Run task',
'task_description'=>'Description',
'task_explain_optimize'=>'Optimizes your database',
'task_explain_post_timespan'=>'Calculates the oldest/youngest posting',
'task_explain_prune_log'=>'Purges expired log entries from database',
'task_explain_prune_request'=>'Purges expired user requests from database',
'task_explain_prune_search'=>'Purges expired search results from database',
'task_explain_prune_user'=>'Purges not activated user accounts from database',
'task_info'=>'Task Information',
'task_interval'=>'Run Interval',
'task_last_run'=>'Last run timestamp',
'task_next_run'=>'Next run (soonest)',
'task_seg_optimize'=>'Task: Optimize forum database',
'task_seg_post_timespan'=>'Task: Create main overview calendar',
'task_seg_prune_log'=>'Task: Purge Log-Records',
'task_seg_prune_request'=>'Task: Prune user requests',
'task_seg_prune_search'=>'Task: Prune search table',
'task_seg_prune_user'=>'Task: Prune user accounts',
'used_ip_addresses'=>'Used IP-Addresses',
'user_group'=>'User Group',
'using_recent_forum_software_version'=>'The update server reports that you are using the most recent version.',
'version'=>'Current version',
'yearly'=>'Yearly'
);
?>
